Documentation
¶
Overview ¶
Package color provides color detection and theming for CLI output.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsTerminal ¶
IsTerminal returns true if the given file descriptor is a terminal.
func Profile ¶
Profile detects the current color profile based on environment variables and flags. Returns true if color output should be enabled.
Color is disabled when any of:
- NO_COLOR env is set (any value, per https://no-color.org)
- CLICOLOR=0
- TERM=dumb
- noColorFlag is true (--no-color CLI flag)
Types ¶
Click to show internal directories.
Click to hide internal directories.